# frozen_string_literal: true

require 'test_helper'

class EvalHelpersBaseTest < StateMachinesTest
  include StateMachines::EvalHelpers

  def default_test; end
end
